@@ -239,7 +239,7 @@ class AzureCli:
     def __init__(self, bin_path=None):
         # azure CLI supported versions interval
         self.min_version = (0, 0, 0)
-        self.max_version = (2, 25, 0)
+        self.max_version = (2, 32, 0)
         # Path to look up for executable
         self.bin_path = None
         # Force azure CLI binary path if bin_path exists and contains
@@ -350,6 +350,7 @@ class AzureCli:
                     "Image %s:%s:%s not available in region %s"
                     % (publisher, offer, sku, region)
                 )
+            return result[0]
         except ValueError:
             # JSON decoding error
             logging.error("Failed to decode JSON data")
@@ -378,6 +379,26 @@ class AzureCli:
                 "--created"
             ])
             logging.debug("Command output: %s", output.decode("utf-8"))
+        except CalledProcessError as e:
+            logging.error("Failed to execute the command: %s", e.cmd)
+            logging.error("Return code is: %s", e.returncode)
+            logging.error("Output: %s", e.output)
+            raise CloudCliError(
+                "Failed to execute the following command, please check the "
+                "logs for details: %s" % e.cmd
+            )
+
+    def accept_terms(self, publisher, offer, sku, version):
+        try:
+            output = exec_shell([
+                self.bin("az"),
+                "vm",
+                "image",
+                "terms",
+                "accept",
+                "--urn %s:%s:%s:%s" % (publisher, offer, sku, version),
+            ])
+            logging.debug("Command output: %s", output.decode("utf-8"))
 
         except CalledProcessError as e:
             logging.error("Failed to execute the command: %s", e.cmd)
@@ -432,7 +453,7 @@ class GCloudCli:
     def __init__(self, bin_path=None):
         # gcloud CLI supported versions interval
         self.min_version = (0, 0, 0)
-        self.max_version = (329, 0, 0)
+        self.max_version = (367, 0, 0)
         # Path to look up for executable
         self.bin_path = None
         # Force gcloud CLI binary path if bin_path exists and contains
@@ -522,14 +543,20 @@ class GCloudCli:
 
     def check_image_availability(self, image):
         try:
-            output = exec_shell([
+            cmd = [
                 self.bin("gcloud"),
                 "compute",
                 "images",
                 "list",
                 "--filter=\"family=%s\"" % image,
                 "--format=json"
-            ])
+            ]
+            if image == 'rocky-linux-8':
+                cmd = cmd + [
+                        '--no-standard-images',
+                        '--project=rocky-linux-cloud'
+                        ]
+            output = exec_shell(cmd)
             result = json.loads(output.decode("utf-8"))
             logging.debug("Command output: %s", result)
             if len(result) == 0 or result[0]['status'] != 'READY':
